from arkindex.documents.models import Element
from arkindex.project.tests import FixtureTestCase


class TestElement(FixtureTestCase):

    @classmethod
    def setUpTestData(cls):
        super().setUpTestData()
        cls.element_type = cls.corpus.types.first()
        cls.image = cls.imgsrv.images.get(path="img1")

    def test_iiif_url(self):
        # Rotation and mirroring should be ignored in iiif_url
        cases = [
            (0, False),
            (0, True),
            (180, False),
            (180, True),
        ]
        for rotation_angle, mirrored in cases:
            with self.subTest(rotation_angle=rotation_angle, mirrored=mirrored):
                element = Element(
                    name="Something",
                    type=self.element_type,
                    image=self.image,
                    polygon=[
                        [10, 20],
                        [40, 20],
                        [40, 60],
                        [10, 60],
                        [10, 20],
                    ],
                    rotation_angle=rotation_angle,
                    mirrored=mirrored,
                )
                self.assertEqual(element.iiif_url, "http://server/img1/10,20,30,40/full/0/default.jpg")

    def test_iiif_thumbnail_url(self):
        cases = [
            (0, False, [[500, 100], [650, 100], [650, 800], [500, 800], [500, 100]], "http://server/img1/500,100,150,700/,400/0/default.jpg"),
            (0, True, [[500, 100], [650, 100], [650, 800], [500, 800], [500, 100]], "http://server/img1/500,100,150,700/,400/!0/default.jpg"),
            (180, False, [[500, 580], [650, 580], [650, 700], [500, 700], [500, 580]], "http://server/img1/500,580,150,120/,120/180/default.jpg"),
            (180, True, [[500, 580], [650, 580], [650, 700], [500, 700], [500, 580]], "http://server/img1/500,580,150,120/,120/!180/default.jpg"),
            (0, False, [[10, 20], [40, 20], [40, 60], [10, 60], [10, 20]], "http://server/img1/10,20,30,40/,40/0/default.jpg"),
            (0, True, [[10, 20], [40, 20], [40, 60], [10, 60], [10, 20]], "http://server/img1/10,20,30,40/,40/!0/default.jpg"),
            (180, False, [[10, 20], [40, 20], [40, 60], [10, 60], [10, 20]], "http://server/img1/10,20,30,40/,40/180/default.jpg"),
            (180, True, [[10, 20], [40, 20], [40, 60], [10, 60], [10, 20]], "http://server/img1/10,20,30,40/,40/!180/default.jpg"),
        ]
        for rotation_angle, mirrored, polygon, expected_url in cases:
            with self.subTest(rotation_angle=rotation_angle, mirrored=mirrored):
                element = Element(
                    name="Something",
                    type=self.element_type,
                    image=self.image,
                    polygon=polygon,
                    rotation_angle=rotation_angle,
                    mirrored=mirrored,
                )
                self.assertEqual(element.iiif_thumbnail_url, expected_url)

    def test_no_image_no_url(self):
        element = Element(
            name="Something",
            type=self.element_type,
        )
        self.assertIsNone(element.iiif_url)
        self.assertIsNone(element.iiif_thumbnail_url)
